@@ -213,7 +213,7 @@ class TestLogStatistics(MLFlowBase):
 
 
 
-class TestLogDataFrame(MLFlowBase):
+class TestLogArtifact(MLFlowBase):
 
     @staticmethod
     def assert_file_exists(temp_file_name, folder):
@@ -240,13 +240,13 @@ class TestLogDataFrame(MLFlowBase):
         return pd.DataFrame({'a' : [1,2,3], 'b' : [40,50,60]})
 
     def test_file_exists(self, monkeypatch, df, mlf_obj):
-        monkeypatch.setattr(mlflow, 'log_artifact', TestLogDataFrame.assert_file_exists)        
-        mlf_obj.log_dataframe(df, 'filename.parquet', 'mlflow_test_folder')
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogArtifact.assert_file_exists)    
+        mlf_obj.log_artifact(df, 'filename.parquet', 'mlflow_test_folder', save_func=df.to_parquet, fname_param_name='path', object_param_name=None)
 
 
     def test_file_correct(self, monkeypatch, df, mlf_obj):
-        monkeypatch.setattr(mlflow, 'log_artifact', TestLogDataFrame.assert_right_content)
-        mlf_obj.log_dataframe(df, 'filename.parquet', 'mlflow_test_folder')
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogArtifact.assert_right_content)
+        mlf_obj.log_artifact(df, 'filename.parquet', 'mlflow_test_folder', save_func=df.to_parquet, fname_param_name='path', object_param_name=None)
 
 
 
@@ -305,10 +305,10 @@ class TestGetMetrics(MLFlowBase):
 
 
 
-class TestGetDataFrame(MLFlowBase):
+class TestGetArtifact(MLFlowBase):
 
     def test_operation_no_folder(self, mlf_obj):
-        df = mlf_obj.get_dataframe('my_df')
+        df = mlf_obj.get_artifact('my_df', load_func=pd.read_parquet)
         assert df.shape[0] == 3
         assert df.shape[1] == 2
         assert df.iloc[0].a == 1
@@ -319,7 +319,7 @@ class TestGetDataFrame(MLFlowBase):
         assert df.iloc[2].b == 33
 
     def test_operation_with_folder(self, mlf_obj):
-        df = mlf_obj.get_dataframe('my_df', 'folder/path')
+        df = mlf_obj.get_artifact('my_df', 'folder/path', load_func=pd.read_parquet)
         assert df.shape[0] == 3
         assert df.shape[1] == 2
         assert df.iloc[0].a == 1
@@ -363,4 +363,118 @@ class TestGetParams(MLFlowBase):
 
     def test_object_view(self, mlf_obj):
         par = mlf_obj.get_params()
-        assert isinstance(par, ObjectView)
\ No newline at end of file
+        assert isinstance(par, ObjectView)
+
+
+class TestLogDataFrame(MLFlowBase):
+    @pytest.fixture
+    def df(self):
+        return pd.DataFrame({'a' : [1,2,3], 'b' : [40,50,60]})
+
+    def test_file_exists(self, monkeypatch, df, mlf_obj):
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogArtifact.assert_file_exists)    
+        mlf_obj.log_dataframe(df, 'filename', 'mlflow_test_folder')
+
+
+    def test_file_correct(self, monkeypatch, df, mlf_obj):
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogArtifact.assert_right_content)
+        mlf_obj.log_dataframe(df, 'filename', 'mlflow_test_folder')
+
+
+class TestLogNumpy(MLFlowBase):
+    @staticmethod
+    def assert_file_exists(temp_file_name, folder):
+        assert os.path.exists(temp_file_name)
+        assert folder == 'mlflow_test_folder'
+
+    @staticmethod
+    def assert_right_content(temp_file_name, folder):
+        df = np.load(temp_file_name)
+        assert df.shape[0] == 2
+        assert df.shape[1] == 3
+
+        assert df[0][0] == 1
+        assert df[0][1] == 2
+        assert df[0][2] == 3
+
+        assert df[1][0] == 40
+        assert df[1][1] == 50
+        assert df[1][2] == 60
+
+
+    @pytest.fixture
+    def df(self):
+        return np.array([[1,2,3],[40,50,60]])
+
+    def test_file_exists(self, monkeypatch, df, mlf_obj):
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogNumpy.assert_file_exists)    
+        mlf_obj.log_numpy(df, 'filename', 'mlflow_test_folder')
+
+
+    def test_file_correct(self, monkeypatch, df, mlf_obj):
+        monkeypatch.setattr(mlflow, 'log_artifact', TestLogNumpy.assert_right_content)
+        mlf_obj.log_numpy(df, 'filename', 'mlflow_test_folder')
+
+
+
+class TestGetDataFrame(MLFlowBase):
+
+    def test_operation_no_folder(self, mlf_obj):
+        df = mlf_obj.get_dataframe('my_df')
+        assert df.shape[0] == 3
+        assert df.shape[1] == 2
+        assert df.iloc[0].a == 1
+        assert df.iloc[0].b == 11
+        assert df.iloc[1].a == 2
+        assert df.iloc[1].b == 22
+        assert df.iloc[2].a == 3
+        assert df.iloc[2].b == 33
+
+    def test_operation_with_folder(self, mlf_obj):
+        df = mlf_obj.get_dataframe('my_df', 'folder/path')
+        assert df.shape[0] == 3
+        assert df.shape[1] == 2
+        assert df.iloc[0].a == 1
+        assert df.iloc[0].b == 11
+        assert df.iloc[1].a == 2
+        assert df.iloc[1].b == 22
+        assert df.iloc[2].a == 3
+        assert df.iloc[2].b == 33
+
+
+
+
+class TestGetNumpy(MLFlowBase):
+
+    @staticmethod
+    def mocked_download_artifacts_numpy(run_id, artifact_path, dst_path):
+        df = np.array([[1,2,3],[11,22,33]])
+        fname = os.path.split(artifact_path)[1]
+        local_name = os.path.join(dst_path, fname + '.npy')
+        np.save(local_name, df)
+        return local_name
+
+
+    def test_operation_no_folder(self, mlf_obj, monkeypatch):
+        monkeypatch.setattr(mlflow.artifacts, 'download_artifacts', TestGetNumpy.mocked_download_artifacts_numpy)
+        df = mlf_obj.get_numpy('my_df')
+        assert df.shape[0] == 2
+        assert df.shape[1] == 3
+        assert df[0][0] == 1
+        assert df[0][1] == 2
+        assert df[0][2] == 3
+        assert df[1][0] == 11
+        assert df[1][1] == 22
+        assert df[1][2] == 33
+
+    def test_operation_with_folder(self, mlf_obj, monkeypatch):
+        monkeypatch.setattr(mlflow.artifacts, 'download_artifacts', TestGetNumpy.mocked_download_artifacts_numpy)
+        df = mlf_obj.get_numpy('my_df', 'folder/path')
+        assert df.shape[0] == 2
+        assert df.shape[1] == 3
+        assert df[0][0] == 1
+        assert df[0][1] == 2
+        assert df[0][2] == 3
+        assert df[1][0] == 11
+        assert df[1][1] == 22
+        assert df[1][2] == 33
